@@ -28,16 +28,16 @@ import (
 	"github.com/Azure/go-autorest/autorest/to"
 	"github.com/ghodss/yaml"
 	"github.com/golang/mock/gomock"
-	clusterv1 "github.com/openshift/cluster-api/pkg/apis/cluster/v1alpha1"
-	machinev1 "github.com/openshift/cluster-api/pkg/apis/machine/v1beta1"
-	"github.com/openshift/cluster-api/pkg/client/clientset_generated/clientset/fake"
-	controllerError "github.com/openshift/cluster-api/pkg/controller/error"
-	"github.com/openshift/cluster-api/pkg/controller/machine"
+	machinev1 "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
+	"github.com/openshift/machine-api-operator/pkg/controller/machine"
+	controllerError "github.com/openshift/machine-api-operator/pkg/controller/machine"
 	"github.com/pkg/errors"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
+	"k8s.io/client-go/kubernetes/scheme"
 	"k8s.io/client-go/tools/record"
+	"k8s.io/klog"
 	"k8s.io/utils/pointer"
 	clusterproviderv1 "sigs.k8s.io/cluster-api-provider-azure/pkg/apis/azureprovider/v1alpha1"
 	machineproviderv1 "sigs.k8s.io/cluster-api-provider-azure/pkg/apis/azureprovider/v1beta1"
@@ -53,6 +53,12 @@ var (
 	_ machine.Actuator = (*Actuator)(nil)
 )
 
+func init() {
+	if err := machinev1.AddToScheme(scheme.Scheme); err != nil {
+		klog.Fatal(err)
+	}
+}
+
 func newClusterProviderSpec() clusterproviderv1.AzureClusterProviderSpec {
 	return clusterproviderv1.AzureClusterProviderSpec{
 		ResourceGroup: "resource-group-test",
@@ -70,16 +76,6 @@ func providerSpecFromMachine(in *machineproviderv1.AzureMachineProviderSpec) (*m
 	}, nil
 }
 
-func providerSpecFromCluster(in *clusterproviderv1.AzureClusterProviderSpec) (*clusterv1.ProviderSpec, error) {
-	bytes, err := yaml.Marshal(in)
-	if err != nil {
-		return nil, err
-	}
-	return &clusterv1.ProviderSpec{
-		Value: &runtime.RawExtension{Raw: bytes},
-	}, nil
-}
-
 func newMachine(t *testing.T, machineConfig machineproviderv1.AzureMachineProviderSpec, labels map[string]string) *machinev1.Machine {
 	providerSpec, err := providerSpecFromMachine(&machineConfig)
 	if err != nil {
@@ -96,41 +92,9 @@ func newMachine(t *testing.T, machineConfig machineproviderv1.AzureMachineProvid
 	}
 }
 
-func newCluster(t *testing.T) *clusterv1.Cluster {
-	clusterProviderSpec := newClusterProviderSpec()
-	providerSpec, err := providerSpecFromCluster(&clusterProviderSpec)
-	if err != nil {
-		t.Fatalf("error encoding provider config: %v", err)
-	}
-
-	return &clusterv1.Cluster{
-		TypeMeta: metav1.TypeMeta{
-			Kind: "Cluster",
-		},
-		ObjectMeta: metav1.ObjectMeta{
-			Name: "cluster-test",
-		},
-		Spec: clusterv1.ClusterSpec{
-			ClusterNetwork: clusterv1.ClusterNetworkingConfig{
-				Services: clusterv1.NetworkRanges{
-					CIDRBlocks: []string{
-						"10.96.0.0/12",
-					},
-				},
-				Pods: clusterv1.NetworkRanges{
-					CIDRBlocks: []string{
-						"192.168.0.0/16",
-					},
-				},
-			},
-			ProviderSpec: *providerSpec,
-		},
-	}
-}
 func newFakeScope(t *testing.T, label string) *actuators.MachineScope {
 	scope := &actuators.Scope{
 		Context: context.Background(),
-		Cluster: newCluster(t),
 		ClusterConfig: &clusterproviderv1.AzureClusterProviderSpec{
 			ResourceGroup:       "dummyResourceGroup",
 			Location:            "dummyLocation",
@@ -140,19 +104,15 @@ func newFakeScope(t *testing.T, label string) *actuators.MachineScope {
 			SAKeyPair:           clusterproviderv1.KeyPair{Cert: []byte("cert"), Key: []byte("key")},
 			DiscoveryHashes:     []string{"discoveryhash0"},
 		},
-		ClusterStatus: &clusterproviderv1.AzureClusterProviderStatus{},
 	}
-	scope.Network().APIServerIP.DNSName = "DummyDNSName"
 	labels := make(map[string]string)
 	labels[machineproviderv1.MachineRoleLabel] = label
 	labels[machinev1.MachineClusterIDLabel] = "clusterID"
 	machineConfig := machineproviderv1.AzureMachineProviderSpec{}
 	m := newMachine(t, machineConfig, labels)
-	c := fake.NewSimpleClientset(m).MachineV1beta1()
 	return &actuators.MachineScope{
-		Scope:         scope,
-		Machine:       m,
-		MachineClient: c.Machines("dummyNamespace"),
+		Scope:   scope,
+		Machine: m,
 		MachineConfig: &machineproviderv1.AzureMachineProviderSpec{
 			Subnet:          "dummySubnet",
 			Vnet:            "dummyVnet",
@@ -606,7 +566,7 @@ func TestMachineEvents(t *testing.T) {
 			machine:    machine,
 			credSecret: invalidAzureCredentialsSecret,
 			operation: func(actuator *Actuator, machine *machinev1.Machine) {
-				actuator.Create(context.TODO(), nil, machine)
+				actuator.Create(context.TODO(), machine)
 			},
 			event: "Warning FailedCreate InvalidConfiguration: failed to create machine \"azure-actuator-testing-machine\" scope: failed to update cluster: Azure client id /azure-credentials-secret did not contain key azure_client_id",
 		},
@@ -615,7 +575,7 @@ func TestMachineEvents(t *testing.T) {
 			machine:    invalidMachine,
 			credSecret: azureCredentialsSecret,
 			operation: func(actuator *Actuator, machine *machinev1.Machine) {
-				actuator.Create(context.TODO(), nil, machine)
+				actuator.Create(context.TODO(), machine)
 			},
 			event: "Warning FailedCreate CreateError: failed to reconcile machine \"azure-actuator-testing-machine\"s: failed to create nic azure-actuator-testing-machine-nic for machine azure-actuator-testing-machine: MachineConfig vnet is missing on machine azure-actuator-testing-machine",
 		},
@@ -624,7 +584,7 @@ func TestMachineEvents(t *testing.T) {
 			machine:    machine,
 			credSecret: azureCredentialsSecret,
 			operation: func(actuator *Actuator, machine *machinev1.Machine) {
-				actuator.Create(context.TODO(), nil, machine)
+				actuator.Create(context.TODO(), machine)
 			},
 			event: fmt.Sprintf("Normal Created Created machine %q", machine.Name),
 		},
@@ -633,25 +593,16 @@ func TestMachineEvents(t *testing.T) {
 			machine:    machine,
 			credSecret: invalidAzureCredentialsSecret,
 			operation: func(actuator *Actuator, machine *machinev1.Machine) {
-				actuator.Update(context.TODO(), nil, machine)
+				actuator.Update(context.TODO(), machine)
 			},
 			event: "Warning FailedUpdate UpdateError: failed to create machine \"azure-actuator-testing-machine\" scope: failed to update cluster: Azure client id /azure-credentials-secret did not contain key azure_client_id",
 		},
-		{
-			name:       "Update machine event failed (reconciler)",
-			machine:    invalidMachine,
-			credSecret: azureCredentialsSecret,
-			operation: func(actuator *Actuator, machine *machinev1.Machine) {
-				actuator.Update(context.TODO(), nil, machine)
-			},
-			event: "Warning FailedUpdate UpdateError: failed to update machine \"azure-actuator-testing-machine\": found attempt to change immutable state",
-		},
 		{
 			name:       "Update machine event succeed",
 			machine:    machine,
 			credSecret: azureCredentialsSecret,
 			operation: func(actuator *Actuator, machine *machinev1.Machine) {
-				actuator.Update(context.TODO(), nil, machine)
+				actuator.Update(context.TODO(), machine)
 			},
 			event: fmt.Sprintf("Normal Updated Updated machine %q", machine.Name),
 		},
@@ -660,7 +611,7 @@ func TestMachineEvents(t *testing.T) {
 			machine:    machine,
 			credSecret: invalidAzureCredentialsSecret,
 			operation: func(actuator *Actuator, machine *machinev1.Machine) {
-				actuator.Delete(context.TODO(), nil, machine)
+				actuator.Delete(context.TODO(), machine)
 			},
 			event: "Warning FailedDelete DeleteError: failed to create machine \"azure-actuator-testing-machine\" scope: failed to update cluster: Azure client id /azure-credentials-secret did not contain key azure_client_id",
 		},
@@ -669,7 +620,7 @@ func TestMachineEvents(t *testing.T) {
 			machine:    invalidMachine,
 			credSecret: azureCredentialsSecret,
 			operation: func(actuator *Actuator, machine *machinev1.Machine) {
-				actuator.Delete(context.TODO(), nil, machine)
+				actuator.Delete(context.TODO(), machine)
 			},
 			event: "Warning FailedDelete DeleteError: failed to delete machine \"azure-actuator-testing-machine\": MachineConfig vnet is missing on machine azure-actuator-testing-machine",
 		},
@@ -678,7 +629,7 @@ func TestMachineEvents(t *testing.T) {
 			machine:    machine,
 			credSecret: azureCredentialsSecret,
 			operation: func(actuator *Actuator, machine *machinev1.Machine) {
-				actuator.Delete(context.TODO(), nil, machine)
+				actuator.Delete(context.TODO(), machine)
 			},
 			event: fmt.Sprintf("Normal Deleted Deleted machine %q", machine.Name),
 		},
@@ -686,7 +637,11 @@ func TestMachineEvents(t *testing.T) {
 
 	for _, tc := range cases {
 		t.Run(tc.name, func(t *testing.T) {
-			cs := controllerfake.NewFakeClient(tc.credSecret)
+			cs := controllerfake.NewFakeClientWithScheme(scheme.Scheme, tc.credSecret)
+
+			if err := cs.Create(context.TODO(), machine); err != nil {
+				t.Fatal(err)
+			}
 
 			mockCtrl := gomock.NewController(t)
 			azSvc := mock_azure.NewMockService(mockCtrl)
@@ -699,7 +654,6 @@ func TestMachineEvents(t *testing.T) {
 			eventsChannel := make(chan string, 1)
 
 			machineActuator := NewActuator(ActuatorParams{
-				Client:     fake.NewSimpleClientset(tc.machine).MachineV1beta1(),
 				CoreClient: cs,
 				ReconcilerBuilder: func(scope *actuators.MachineScope) *Reconciler {
 					return &Reconciler{
@@ -797,7 +751,6 @@ func TestStatusCodeBasedCreationErrors(t *testing.T) {
 			eventsChannel := make(chan string, 1)
 
 			machineActuator := NewActuator(ActuatorParams{
-				Client:     fake.NewSimpleClientset(machine).MachineV1beta1(),
 				CoreClient: cs,
 				ReconcilerBuilder: func(scope *actuators.MachineScope) *Reconciler {
 					return &Reconciler{
@@ -819,7 +772,7 @@ func TestStatusCodeBasedCreationErrors(t *testing.T) {
 			vmSvc.EXPECT().CreateOrUpdate(gomock.Any(), gomock.Any()).Return(wrapErr).Times(1)
 			vmSvc.EXPECT().Get(gomock.Any(), gomock.Any()).Return(nil, autorest.NewError("compute.VirtualMachinesClient", "Get", "MOCK")).Times(1)
 
-			_, ok := machineActuator.Create(context.TODO(), nil, machine).(*controllerError.RequeueAfterError)
+			_, ok := machineActuator.Create(context.TODO(), machine).(*controllerError.RequeueAfterError)
 			if ok && !tc.requeable {
 				t.Error("Error is not requeable but was requeued")
 			}
